@@ -1,10 +1,10 @@
 package List::Objects::WithUtils::Role::Hash::Immutable;
 {
-  $List::Objects::WithUtils::Role::Hash::Immutable::VERSION = '2.002001';
+  $List::Objects::WithUtils::Role::Hash::Immutable::VERSION = '2.002002';
 }
 use strictures 1;
 use Carp ();
-use Hash::Util ();
+use Tie::Hash ();
 
 sub _make_unimp {
   my ($method) = @_;
@@ -26,17 +26,23 @@ requires 'new', @ImmutableMethods;
 around is_mutable => sub { () };
 
 around new => sub {
-  my $orig = shift;
-  my $self = $orig->(@_);
+  my ($orig, $class) = splice @_, 0, 2;
+  my $self = $class->$orig(@_);
 
-  if (my $obj = tied %$self) {
-    Role::Tiny->apply_roles_to_object( $obj,
-      'List::Objects::WithUtils::Role::Hash::TiedRO'
-    );
+
+  # This behavior changed in c. 45f59a73 --
+  # we can revert back if Hash::Util gains the flexibility discussed on p5p
+  # (lock_keys without an exception on unknown key retrieval)
+  # For now, take the tie performance hit :(
+
+  unless (tied %$self) {
+    tie %$self, 'Tie::StdHash';
+    %$self = @_;
   }
 
-  Hash::Util::lock_keys(%$self);
-  Hash::Util::lock_value(%$self, $_) for keys %$self;
+  Role::Tiny->apply_roles_to_object( tied(%$self),
+    'List::Objects::WithUtils::Role::Hash::TiedRO'
+  );
 
   $self
 };
@@ -69,7 +75,7 @@ The following methods are not available and will throw an exception:
   set
   delete
 
-(The backing hash is also marked read-only, but see L<Hash::Util/"CAVEATS">)
+(The backing hash is also marked read-only.)
 
 See L<List::Objects::WithUtils::Hash::Immutable> for a consumer
 implementation.
